@@ -71,25 +71,25 @@ func (b *DiscoveryOptionsBuilder) BuildOptions(o interface{}) error {
 				return fmt.Errorf("locationStore=%q is of unexpected type %T", store, base)
 			}
 		} else {
-			if supportsPublicJWKS(clusterSpec) {
-				serviceAccountIssuer = "https://" + clusterSpec.MasterPublicName
+			if supportsPublicJWKS(clusterSpec) && clusterSpec.API.PublicName != "" {
+				serviceAccountIssuer = "https://" + clusterSpec.API.PublicName
 			} else {
-				serviceAccountIssuer = "https://" + clusterSpec.MasterInternalName
+				serviceAccountIssuer = "https://api.internal." + b.ClusterName
 			}
 		}
 		kubeAPIServer.ServiceAccountIssuer = &serviceAccountIssuer
 	}
-	kubeAPIServer.ServiceAccountJWKSURI = fi.String(*kubeAPIServer.ServiceAccountIssuer + "/openid/v1/jwks")
+	kubeAPIServer.ServiceAccountJWKSURI = fi.PtrTo(*kubeAPIServer.ServiceAccountIssuer + "/openid/v1/jwks")
 	// We set apiserver ServiceAccountKey and ServiceAccountSigningKeyFile in nodeup
 
 	return nil
 }
 
 func supportsPublicJWKS(clusterSpec *kops.ClusterSpec) bool {
-	if !fi.BoolValue(clusterSpec.KubeAPIServer.AnonymousAuth) {
+	if !fi.ValueOf(clusterSpec.KubeAPIServer.AnonymousAuth) {
 		return false
 	}
-	for _, cidr := range clusterSpec.KubernetesAPIAccess {
+	for _, cidr := range clusterSpec.API.Access {
 		if cidr == "0.0.0.0/0" || cidr == "::/0" {
 			return true
 		}
