@@ -17,6 +17,7 @@ limitations under the License.
 package awstasks
 
 import (
+	"context"
 	"reflect"
 	"testing"
 
@@ -28,19 +29,21 @@ import (
 )
 
 func TestVPCCreate(t *testing.T) {
+	ctx := context.TODO()
+
 	cloud := awsup.BuildMockAWSCloud("us-east-1", "abc")
 	c := &mockec2.MockEC2{}
 	cloud.MockEC2 = c
 
 	// We define a function so we can rebuild the tasks, because we modify in-place when running
-	buildTasks := func() map[string]fi.Task {
+	buildTasks := func() map[string]fi.CloudupTask {
 		vpc1 := &VPC{
 			Name:      s("vpc1"),
 			Lifecycle: fi.LifecycleSync,
 			CIDR:      s("172.21.0.0/16"),
 			Tags:      map[string]string{"Name": "vpc1"},
 		}
-		return map[string]fi.Task{
+		return map[string]fi.CloudupTask{
 			"vpc1": vpc1,
 		}
 	}
@@ -53,17 +56,16 @@ func TestVPCCreate(t *testing.T) {
 			Cloud: cloud,
 		}
 
-		context, err := fi.NewContext(target, nil, cloud, nil, nil, nil, true, allTasks)
+		context, err := fi.NewCloudupContext(ctx, target, nil, cloud, nil, nil, nil, allTasks)
 		if err != nil {
 			t.Fatalf("error building context: %v", err)
 		}
-		defer context.Close()
 
 		if err := context.RunTasks(testRunTasksOptions); err != nil {
 			t.Fatalf("unexpected error during Run: %v", err)
 		}
 
-		if fi.StringValue(vpc1.ID) == "" {
+		if fi.ValueOf(vpc1.ID) == "" {
 			t.Fatalf("ID not set after create")
 		}
 
@@ -73,7 +75,7 @@ func TestVPCCreate(t *testing.T) {
 
 		expected := &ec2.Vpc{
 			CidrBlock: s("172.21.0.0/16"),
-			IsDefault: fi.Bool(false),
+			IsDefault: fi.PtrTo(false),
 			VpcId:     vpc1.ID,
 			Tags: buildTags(map[string]string{
 				"Name": "vpc1",
@@ -91,7 +93,7 @@ func TestVPCCreate(t *testing.T) {
 	{
 		allTasks := buildTasks()
 
-		checkNoChanges(t, cloud, allTasks)
+		checkNoChanges(t, ctx, cloud, allTasks)
 	}
 }
 
@@ -132,6 +134,8 @@ func Test4758(t *testing.T) {
 }
 
 func TestSharedVPCAdditionalCIDR(t *testing.T) {
+	ctx := context.TODO()
+
 	cloud := awsup.BuildMockAWSCloud("us-east-1", "abc")
 	c := &mockec2.MockEC2{}
 	c.CreateVpcWithId(&ec2.CreateVpcInput{
@@ -156,15 +160,15 @@ func TestSharedVPCAdditionalCIDR(t *testing.T) {
 	cloud.MockEC2 = c
 
 	// We define a function so we can rebuild the tasks, because we modify in-place when running
-	buildTasks := func() map[string]fi.Task {
+	buildTasks := func() map[string]fi.CloudupTask {
 		vpc1 := &VPC{
 			Name:      s("vpc-1"),
 			Lifecycle: fi.LifecycleSync,
 			CIDR:      s("172.21.0.0/16"),
 			Tags:      map[string]string{"Name": "vpc-1"},
-			Shared:    fi.Bool(true),
+			Shared:    fi.PtrTo(true),
 		}
-		return map[string]fi.Task{
+		return map[string]fi.CloudupTask{
 			"vpc-1": vpc1,
 		}
 	}
@@ -177,17 +181,16 @@ func TestSharedVPCAdditionalCIDR(t *testing.T) {
 			Cloud: cloud,
 		}
 
-		context, err := fi.NewContext(target, nil, cloud, nil, nil, nil, true, allTasks)
+		context, err := fi.NewCloudupContext(ctx, target, nil, cloud, nil, nil, nil, allTasks)
 		if err != nil {
 			t.Fatalf("error building context: %v", err)
 		}
-		defer context.Close()
 
 		if err := context.RunTasks(testRunTasksOptions); err != nil {
 			t.Fatalf("unexpected error during Run: %v", err)
 		}
 
-		if fi.StringValue(vpc1.ID) == "" {
+		if fi.ValueOf(vpc1.ID) == "" {
 			t.Fatalf("ID not set")
 		}
 
@@ -197,7 +200,7 @@ func TestSharedVPCAdditionalCIDR(t *testing.T) {
 
 		expected := &ec2.Vpc{
 			CidrBlock: s("172.21.0.0/16"),
-			IsDefault: fi.Bool(false),
+			IsDefault: fi.PtrTo(false),
 			VpcId:     vpc1.ID,
 			Tags: buildTags(map[string]string{
 				"Name": "vpc-1",
