@@ -19,7 +19,7 @@ package azuretasks
 import (
 	"context"
 
-	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2020-06-01/compute"
+	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2022-08-01/compute"
 	"github.com/Azure/go-autorest/autorest/to"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
@@ -35,11 +35,13 @@ type Disk struct {
 	ResourceGroup *ResourceGroup
 	SizeGB        *int32
 	Tags          map[string]*string
+	Zones         *[]string
 }
 
 var (
-	_ fi.Task          = &Disk{}
-	_ fi.CompareWithID = &Disk{}
+	_ fi.CloudupTask          = &Disk{}
+	_ fi.CompareWithID        = &Disk{}
+	_ fi.CloudupTaskNormalize = &Disk{}
 )
 
 // CompareWithID returns the Name of the Disk.
@@ -48,8 +50,8 @@ func (d *Disk) CompareWithID() *string {
 }
 
 // Find discovers the Disk in the cloud provider.
-func (d *Disk) Find(c *fi.Context) (*Disk, error) {
-	cloud := c.Cloud.(azure.AzureCloud)
+func (d *Disk) Find(c *fi.CloudupContext) (*Disk, error) {
+	cloud := c.T.Cloud.(azure.AzureCloud)
 	l, err := cloud.Disk().List(context.TODO(), *d.ResourceGroup.Name)
 	if err != nil {
 		return nil, err
@@ -73,13 +75,18 @@ func (d *Disk) Find(c *fi.Context) (*Disk, error) {
 		},
 		SizeGB: found.DiskSizeGB,
 		Tags:   found.Tags,
+		Zones:  found.Zones,
 	}, nil
 }
 
+func (d *Disk) Normalize(c *fi.CloudupContext) error {
+	c.T.Cloud.(azure.AzureCloud).AddClusterTags(d.Tags)
+	return nil
+}
+
 // Run implements fi.Task.Run.
-func (d *Disk) Run(c *fi.Context) error {
-	c.Cloud.(azure.AzureCloud).AddClusterTags(d.Tags)
-	return fi.DefaultDeltaRunMethod(d, c)
+func (d *Disk) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(d, c)
 }
 
 // CheckChanges returns an error if a change is not allowed.
@@ -102,9 +109,9 @@ func (*Disk) CheckChanges(a, e, changes *Disk) error {
 // RenderAzure creates or updates a Disk.
 func (*Disk) RenderAzure(t *azure.AzureAPITarget, a, e, changes *Disk) error {
 	if a == nil {
-		klog.Infof("Creating a new Disk with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Creating a new Disk with name: %s", fi.ValueOf(e.Name))
 	} else {
-		klog.Infof("Updating a Disk with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Updating a Disk with name: %s", fi.ValueOf(e.Name))
 	}
 	name := *e.Name
 
@@ -116,7 +123,8 @@ func (*Disk) RenderAzure(t *azure.AzureAPITarget, a, e, changes *Disk) error {
 			},
 			DiskSizeGB: e.SizeGB,
 		},
-		Tags: e.Tags,
+		Tags:  e.Tags,
+		Zones: e.Zones,
 	}
 
 	return t.Cloud.Disk().CreateOrUpdate(
