@@ -42,9 +42,8 @@ const (
 	subnetNatAllIPRanges = "ALL_IP_RANGES"
 )
 
-// +kops:fitask
-
 // Router is a Router task.
+// +kops:fitask
 type Router struct {
 	Name      *string
 	Lifecycle fi.Lifecycle
@@ -66,8 +65,8 @@ func (r *Router) CompareWithID() *string {
 }
 
 // Find discovers the Router in the cloud provider.
-func (r *Router) Find(c *fi.Context) (*Router, error) {
-	cloud := c.Cloud.(gce.GCECloud)
+func (r *Router) Find(c *fi.CloudupContext) (*Router, error) {
+	cloud := c.T.Cloud.(gce.GCECloud)
 
 	found, err := cloud.Compute().Routers().Get(cloud.Project(), *r.Region, *r.Name)
 	if err != nil {
@@ -89,8 +88,8 @@ func (r *Router) Find(c *fi.Context) (*Router, error) {
 	actual := &Router{
 		Name:                          &found.Name,
 		Lifecycle:                     r.Lifecycle,
-		Network:                       &Network{Name: fi.String(lastComponent(found.Network))},
-		Region:                        fi.String(lastComponent(found.Region)),
+		Network:                       &Network{Name: fi.PtrTo(lastComponent(found.Network))},
+		Region:                        fi.PtrTo(lastComponent(found.Region)),
 		NATIPAllocationOption:         &nat.NatIpAllocateOption,
 		SourceSubnetworkIPRangesToNAT: &nat.SourceSubnetworkIpRangesToNat,
 	}
@@ -119,8 +118,8 @@ func (r *Router) url(project string) string {
 }
 
 // Run implements fi.Task.Run.
-func (r *Router) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(r, c)
+func (r *Router) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(r, c)
 }
 
 // CheckChanges returns an error if a change is not allowed.
@@ -147,7 +146,7 @@ func (*Router) CheckChanges(a, e, changes *Router) error {
 func (*Router) RenderGCE(t *gce.GCEAPITarget, a, e, changes *Router) error {
 	cloud := t.Cloud
 	project := cloud.Project()
-	region := fi.StringValue(e.Region)
+	region := fi.ValueOf(e.Region)
 
 	if a == nil {
 		klog.V(2).Infof("Creating Cloud NAT Gateway %v", e.Name)
